-- LegacySelector class. Presents a compact list of legacies for multi-selection. Displays total cost of a legacy at max tier & rank as an indicator of "cheapness"
-- Size: 350x256
import "Turbine.UI";

import "Equendil.UI.Resources";
import "Equendil.LIP.Legacy";

-- items used in the listbox
local LegacyItem = class( Turbine.UI.Control );
function LegacyItem:Constructor( legacy )
	Turbine.UI.Control.Constructor( self );

	self.legacy = legacy;
	self.isSelected = false;
	
	self:SetBackColor( Turbine.UI.Color( 0, 0, 0, 0 ) );
	self:SetBackColorBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	self:SetSize( 340, 16 );

	self.iconType = Turbine.UI.Control();
	self.iconType:SetParent( self );
	self.iconType:SetSize( 16, 16 );
	self.iconType:SetPosition( 0, 0 );
	self.iconType:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	self.iconType:SetMouseVisible( false );
	
	self.labelName = Turbine.UI.Label();
	self.labelName:SetParent( self );
	self.labelName:SetSize( 260, 16 );
	self.labelName:SetPosition( 20, 0 );
	self.labelName:SetFont( Turbine.UI.Lotro.Font.Verdana14 );
	self.labelName:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleLeft );
	self.labelName:SetForeColor( Turbine.UI.Color( 1, 1, 1, 1 ) );
	self.labelName:SetMouseVisible( false );

	self.iconCost = Turbine.UI.Control();
	self.iconCost:SetParent( self );
	self.iconCost:SetSize( 16, 16 );
	self.iconCost:SetPosition( 290, 0 );
	self.iconCost:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	self.iconCost:SetBackground( Equendil.UI.Icon.CostSmall );
	self.iconCost:SetMouseVisible( false );
	
	self.labelTotalCost = Turbine.UI.Label();
	self.labelTotalCost:SetParent( self );
	self.labelTotalCost:SetSize( 30,16 );
	self.labelTotalCost:SetPosition( 310, 0 );
	self.labelTotalCost:SetFont( Turbine.UI.Lotro.Font.Verdana14 );
	self.labelTotalCost:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleLeft );
	self.labelTotalCost:SetForeColor( Turbine.UI.Color( 1, 1, 1, 1 ) );
	self.labelTotalCost:SetMouseVisible( false );
	
	self:SetMouseVisible( true );
	self.MouseClick = function( sender, args ) self:ToggleSelection() end
	
	self:SetSelection( legacy:IsActive() );
	
	self:Update();
end

function LegacyItem:Update()
	if self.legacy:GetType() == Equendil.LIP.Type.Major then
		self.iconType:SetBackground( Equendil.UI.Icon.LegacyMajor );
	else
		self.iconType:SetBackground( Equendil.UI.Icon.LegacyMinor );
	end
	
	self.labelName:SetText( self.legacy:GetName() );
	local totalCost = self.legacy:GetTotalCostOf( self.legacy:GetMaxTier(), self.legacy:GetMaxRank() );
	self.labelTotalCost:SetText( tostring( totalCost ) );
end

function LegacyItem:ToggleSelection()
	self.isSelected = not self.isSelected;
	if self.isSelected then
		self:SetBackColor( Turbine.UI.Color( 0.3, 1, 1, 1 ) );
	else
		self:SetBackColor( Turbine.UI.Color( 0, 0, 0, 0 ) );
	end
	self.legacy:SetActive( self.isSelected );
end

function LegacyItem:SetSelection( value )
	self.isSelected = value;
	if self.isSelected then
		self:SetBackColor( Turbine.UI.Color( 0.3, 1, 1, 1 ) );
	else
		self:SetBackColor( Turbine.UI.Color( 0, 0, 0, 0 ) );
	end
end

function LegacyItem:IsSelected()
	return self.isSelected;
end

function LegacyItem:GetLegacy()
	return self.legacy;
end

LegacySelector = class( Turbine.UI.Control );
function LegacySelector:Constructor()
	Turbine.UI.Control.Constructor( self );
	
	self.legacyItems = {};
	
	self:SetSize( 350, 256 );
	
	-- standard scrollbar & listbox, items will handled their own selection
	self.scrollbar = Turbine.UI.Lotro.ScrollBar();
	self.scrollbar:SetOrientation( Turbine.UI.Orientation.Vertical );
	self.scrollbar:SetParent( self );
	self.scrollbar:SetPosition( 340, 0 );
	self.scrollbar:SetSize( 10, 256 );
	
	self.legacyList = Turbine.UI.ListBox();
    self.legacyList:SetParent( self );
    self.legacyList:SetBackColor( Turbine.UI.Color( 0.1, 0, 0, 0 ) );
    self.legacyList:SetPosition( 0, 0 );
    self.legacyList:SetSize( 340, 256 );
	self.legacyList:SetBackColorBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	self.legacyList:SetVerticalScrollBar( self.scrollbar );
	self.legacyList:SetMouseVisible( false );
end

function LegacySelector:AddLegacy( legacy )
	local legacyItem = LegacyItem( legacy );
	table.insert( self.legacyItems, 1, legacyItem );
	self.legacyList:AddItem( legacyItem );
end

function LegacySelector:RemoveLegacy( legacy )
	-- not needed, UNIMPLEMENTED
end

function LegacySelector:Clear()
	self.legacyList:ClearItems();
	self.legacies = {};
end

function LegacySelector:GetSelectedLegacies()
	local selectedLegacies = {};
	for k, v in pairs( self.legacyItems ) do
		if v.IsSelected() then
			table.insert( selectedLegacies, 1, v.GetLegacy() );
		end
	end
	
	return selectedLegacies;
end